package sysinfo

import "strings"

// SystemData lives with this collector.

type SystemData struct {
	Timestamp  string `json:"timestamp"`
	ID         string `json:"id"`
	Distro     string `json:"distro"`
	LSBRel     string `json:"lsb_release"`
	Uname      string `json:"uname"`
	CPUInfo    string `json:"cpuinfo"`
	MemInfo    string `json:"meminfo"`
	Dmidecode  string `json:"dmidecode,omitempty"`
}

func (a *App) collectSystem(s *Snapshot, now string) error {
	sys := &SystemData{
		Timestamp: now,
		LSBRel:    a.safeRun("lsb_release", "-a"),
		Uname:     a.safeRun("uname", "-a"),
		CPUInfo:   a.safeRead("/proc/cpuinfo"),
		MemInfo:   a.safeRead("/proc/meminfo"),
		Dmidecode: a.safeRun("dmidecode"),
		Distro:    "ubuntu",
	}

	if id := strings.TrimSpace(
		a.safeRun("dmidecode", "-s", "system-serial-number")); id != "" {
		sys.ID = id
	} else {
		sys.ID = a.primaryMAC()
	}

	s.System = sys
	return nil
}
